abacusai.categorical_range_violation — AbacusAI documentation

# abacusai.categorical_range_violation

## Classes

`CategoricalRangeViolation` | Summary of important range mismatches for a numerical feature discovered by a model monitoring instance

## Module Contents

class abacusai.categorical_range_violation.CategoricalRangeViolation(client, name=None, mostCommonValues=None, freqOutsideTrainingRange=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Summary of important range mismatches for a numerical feature discovered by a model monitoring instance

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - name (str) – Name of feature.

    - mostCommonValues (list[str]) – List of most common feature names in the prediction distribution not present in the training distribution.

    - freqOutsideTrainingRange (float) – Frequency of prediction rows outside training distribution for the specified feature.

  name
  most_common_values
  freq_outside_training_range
  deprecated_keys
  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict